@@ -294,34 +294,23 @@ def main():
 
                 if message.find('ERROR: failed to reproduce') >= 0:
                     print()
+                    print('#####+++++#####+++++#####+++++#####+++++#####+++++#####+++++#####+++++#####')
                     print()
+                    print(message[:message.find('Traceback (most recent call last):')])
                     print()
+                    print('#####+++++#####+++++#####+++++#####+++++#####+++++#####+++++#####+++++#####')
                     print()
-                    print()
-                    print()
-                    print()
-                    print()
-                    print()
-                    print()
-                    print()
-                    print()
-                    print(message)
-                    print()
-                    print()
-                    print()
-                    print()
-                    print()
-                    print()
-                    print()
-                    print()
-                    print()
-                    print()
-                    print()
-                    print()
-                    print()
-                    raise RuntimeError(message)
+                    raise RuntimeError(bcolors.FAIL+message[
+                                                    message.find('Traceback (most recent call last):'):]
+                                       +bcolors.ENDC)
                 else:
+                    print()
+                    print('#####+++++#####+++++#####+++++#####+++++#####+++++#####+++++#####+++++#####')
+                    print()
                     print(message)
+                    print()
+                    print('#####+++++#####+++++#####+++++#####+++++#####+++++#####+++++#####+++++#####')
+                    print()
             else:
                 print('WARNING: A file that should be execute ('+f+') does not ends with .dvc. The job is skipped!')
         subprocess.call(['git','add','stdout_stderr/*'])
